bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments.get_instance_conversion_kwargs
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaMoments.get_instance_conversion_kwargs